"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require("./_");
const Event_1 = require("./Event");
class ServiceItem {
    constructor(_channel, _networkId, _serviceId, _name, _type, _logoId, _logoData, _remoteControlKeyId) {
        this._channel = _channel;
        this._networkId = _networkId;
        this._serviceId = _serviceId;
        this._name = _name;
        this._type = _type;
        this._logoId = _logoId;
        this._logoData = _logoData;
        this._remoteControlKeyId = _remoteControlKeyId;
        this._id = ServiceItem.getId(_networkId, _serviceId);
    }
    static getId(networkId, serviceId) {
        return parseInt(networkId + (serviceId / 100000).toFixed(5).slice(2), 10);
    }
    get id() {
        return this._id;
    }
    get networkId() {
        return this._networkId;
    }
    get serviceId() {
        return this._serviceId;
    }
    get name() {
        return this._name || "";
    }
    set name(name) {
        if (this._name !== name) {
            this._name = name;
            _1.default.service.save();
            this._updated();
        }
    }
    get type() {
        return this._type;
    }
    set type(type) {
        if (this._type !== type) {
            this._type = type;
            _1.default.service.save();
            this._updated();
        }
    }
    get logoId() {
        return this._logoId;
    }
    set logoId(logoId) {
        if (this._logoId !== logoId) {
            this._logoId = logoId;
            _1.default.service.save();
            this._updated();
        }
    }
    get logoData() {
        return Buffer.from(this._logoData, "base64");
    }
    set logoData(logo) {
        if (this._logoData !== logo.toString("base64")) {
            this._logoData = logo.toString("base64");
            _1.default.service.save();
            this._updated();
        }
    }
    get hasLogoData() {
        return !!this._logoData;
    }
    get remoteControlKeyId() {
        return this._remoteControlKeyId;
    }
    set remoteControlKeyId(id) {
        if (this._remoteControlKeyId !== id) {
            this._remoteControlKeyId = id;
            _1.default.service.save();
            this._updated();
        }
    }
    get channel() {
        return this._channel;
    }
    export(full = false) {
        const ret = {
            id: this._id,
            serviceId: this._serviceId,
            networkId: this._networkId,
            name: this._name || "",
            type: this._type,
            logoId: this._logoId,
            remoteControlKeyId: this._remoteControlKeyId,
            channel: {
                type: this._channel.type,
                channel: this._channel.channel
            }
        };
        if (full === true) {
            ret.logoData = this._logoData;
        }
        return ret;
    }
    getStream(user) {
        return _1.default.tuner.getServiceStream(this, user);
    }
    _updated() {
        Event_1.default.emit("service", "update", this.export());
    }
}
exports.default = ServiceItem;

//# sourceMappingURL=ServiceItem.js.map
